==========
 Tutorial
==========

This tutorial will start from the assumption that you already have an app which
hard codes a single language. This is the ‘source language’, and we'll assume
it's English for simplicity.

If you are already using another i18n/translation solution, it should be obvious
how to adapt this tutorial for your situation.

TODO!!!
